Installation
============

:py:mod:`kinisi` can be installed from the PyPI package manager with :py:mod:`pip`:

.. code-block:: bash 

   pip install kinisi

Alternatively, the latest development build can be found `Github`_. 

.. _Github: https://github.com/bjmorgan/kinisi